from datetime import datetime
import time
import os
import sys
import pytest

from test.data import EVERYDAY_OBJECT_DETECTOR_ID, TEST_S3_VIDEO_URL, TEST_S3_VIDEO_URL_2, TEST_VIDEO_URL, RANDOM_MONGO_ID
from matroid.error import InvalidQueryError, APIError
from test.helper import print_test_pass


class TestStreams(object):
  def test_stream(self, set_up_client):
    stream_id = None
    stream_id_2 = None
    monitoring_id = None

    stream_name = 'py-test-stream-{}'.format(datetime.now())
    stream_name_2 = 'py-test-stream-2-{}'.format(datetime.now())
    thresholds = {'cat': 0.5, 'dog': 0.6}
    task_name = 'test-task'

    # set up client
    self.api = set_up_client

    # start testing
    try:
      stream_id = self.create_stream_test(
          url=TEST_S3_VIDEO_URL, name=stream_name)
      stream_id_2 = self.register_stream_test(
          url=TEST_S3_VIDEO_URL_2, name=stream_name_2)
      monitoring_id = self.monitor_stream_test(
          stream_id=stream_id, detector_id=EVERYDAY_OBJECT_DETECTOR_ID, thresholds=thresholds, task_name=task_name)
      self.search_monitorings_test(
          stream_id=stream_id, monitoring_id=monitoring_id)
      self.search_streams_test()
      self.get_monitoring_result_test(monitoring_id=monitoring_id)
    finally:
      if monitoring_id:
        self.kill_monitoring_test(monitoring_id=monitoring_id)
        self.wait_for_monitoring_stop(monitoring_id=monitoring_id)
        self.delete_monitoring_test(monitoring_id=monitoring_id)
      if stream_id:
        self.delete_stream_test(stream_id=stream_id)
      if stream_id_2:
        self.delete_stream_test(stream_id=stream_id_2)

  # test cases
  def create_stream_test(self, url, name):
    res = self.api.create_stream(
        url=url,
        name=name
    )
    assert (res['streamId'] != None)

    with pytest.raises(APIError) as e:
      self.api.create_stream(url=url, name=name)
    assert ('invalid_query_err' in str(e))

    print_test_pass()
    return res['streamId']

  def register_stream_test(self, url, name):
    res = self.api.register_stream(
      url=url,
      name=name
    )
    assert (res['streamId'] != None)

    with pytest.raises(APIError) as e:
      self.api.register_stream(url=url, name=name)
    assert ('invalid_query_err' in str(e))

    print_test_pass()
    return res['streamId']

  def monitor_stream_test(self, stream_id, detector_id, thresholds, task_name):
    end_time = '5 minutes'

    with pytest.raises(APIError) as e:
      self.api.monitor_stream(streamId=RANDOM_MONGO_ID, detectorId=detector_id,
                              thresholds=thresholds, endTime=end_time, taskName=task_name)
    assert ('invalid_query_err' in str(e))

    res = self.api.monitor_stream(streamId=stream_id, detectorId=detector_id,
                                  thresholds=thresholds, endTime=end_time, taskName=task_name)
    assert(res['monitoringId'] != None)

    print_test_pass()
    return res['monitoringId']

  def search_monitorings_test(self, stream_id, monitoring_id):
    res = self.api.search_monitorings(streamId=stream_id)
    assert (res[0]['monitoringId'] == monitoring_id)
    print_test_pass()

  def search_streams_test(self):
    res = self.api.search_streams(permission='private')
    assert (res[0]['streamId'] != None)
    print_test_pass()

  def get_monitoring_result_test(self, monitoring_id):
    res = self.api.get_monitoring_result(monitoringId=monitoring_id)
    assert (res != None)
    print_test_pass()

  def kill_monitoring_test(self, monitoring_id):
    res = self.api.kill_monitoring(monitoringId=monitoring_id)
    assert (res['message'] == 'Successfully killed monitoring.')
    print_test_pass()

  def delete_monitoring_test(self, monitoring_id):
    res = self.api.delete_monitoring(monitoringId=monitoring_id)
    assert (res['message'] == 'Successfully deleted monitoring.')
    print_test_pass()

  def delete_stream_test(self, stream_id):
    res = self.api.delete_stream(streamId=stream_id)
    assert (res['message'] == 'Successfully deleted stream.')
    print_test_pass()

  # helpers
  def wait_for_monitoring_stop(self, monitoring_id):
    print('Info: waiting for monitoring to stop')
    res = self.api.search_monitorings(monitoringId=monitoring_id)

    num_tried = 0
    max_tries = 15
    while (res[0]['state'] != 'failed' and res[0]['state'] != 'scheduled'):
      if num_tried > max_tries:
        pytest.fail('Timeout when waiting for monitoring to stop')

      res = self.api.search_monitorings(monitoringId=monitoring_id)
      time.sleep(2)

      num_tried += 1

    print('Info: monitoring stopped.')



import os
import time
from datetime import datetime
import pytest

from test.data import TEST_IMAGE_FILE, RANDOM_MONGO_ID
from matroid.error import APIConnectionError, InvalidQueryError, APIError
from test.helper import print_test_pass

DETECTOR_TEST_ZIP = os.getcwd() + '/test/test_file/cat-dog-lacroix.zip'


class TestDetectorsAndLabels(object):
  def test_detector_and_labels(self, set_up_client):
    detector_id = None
    import_detector_id = None
    redo_detector_id = None

    detector_name = 'py-test-detector-{}'.format(datetime.now())
    label_name = 'py-test-label'
    bbox = {'left': 0.2, 'top': 0.1, 'width': 0.6, 'height': 0.8}

    # Info for import_detector_test
    import_detector_name = 'upload_py_gender_facial'
    detector_type = 'facial_recognition'
    input_tensor = 'input_5[128,128,3]'
    output_tensor = 'prob3[2]'
    labels = ['female', 'male']
    file_proto = os.getcwd() + '/test/test_file/gender_only_all_android.pb'

    # set up client
    self.api = set_up_client

    # start testing
    try:
      self.delete_pending_detectors()
      detector_id = self.create_detector_test(
          file=DETECTOR_TEST_ZIP, name=detector_name, detector_type='general')
      self.wait_detector_ready_for_edit(detector_id)
      label_id = self.create_label_with_images_with_images_test(
          name=label_name, detector_id=detector_id, image_files=TEST_IMAGE_FILE)
      self.get_annotations_test(
          detector_id=detector_id, label_id=label_id)
      image_id = self.get_label_images_test(
          detector_id=detector_id, label_id=label_id)
      self.update_annotations_test(
          detector_id=detector_id, label_id=label_id, image_id=image_id, bbox=bbox)
      self.update_label_with_images_test(
          detector_id=detector_id, label_id=label_id, image_files=TEST_IMAGE_FILE)
      self.delete_label_test(detector_id=detector_id, label_id=label_id)
      self.finalize_detector_test(detector_id=detector_id)

      self.wait_detector_training(detector_id)

      self.get_detector_info_test(detector_id=detector_id)
      self.search_detectors_test()
      self.list_detectors_test()
      redo_detector_id = self.redo_detector_test(
          detector_id=detector_id)
      import_detector_id = self.import_detector_test(name=import_detector_name, input_tensor=input_tensor,
                                                     output_tensor=output_tensor, detector_type='facial_recognition',
                                                     file_proto=file_proto, labels=labels)
    finally:
      if detector_id:
        self.delete_detector_test(detector_id, 'main detector')
      if import_detector_id:
        self.delete_detector_test(
            import_detector_id, 'imported detector')
      if redo_detector_id:
        self.delete_detector_test(redo_detector_id, 'redo detector')

  def create_detector_test(self, file, name, detector_type):
    with pytest.raises(APIConnectionError) as e:
      invalid_zip_path = os.getcwd() + '/test/test_file/invalid.zip'
      self.api.create_detector(
          file=invalid_zip_path, name=name, detectorType=detector_type)
    assert ('No such file or directory' in str(e))

    res = self.api.create_detector(
        file=file, name=name, detectorType=detector_type)
    assert(res['detectorId'] != None)

    print_test_pass()
    return res['detectorId']

  def create_label_with_images_with_images_test(self, name, detector_id, image_files):
    with pytest.raises(APIError) as e:
      self.api.create_label_with_images(detectorId=RANDOM_MONGO_ID,
                                        name=name, imageFiles=image_files)
    assert ('invalid_query_err' in str(e))

    res = self.api.create_label_with_images(detectorId=detector_id,
                                            name=name, imageFiles=image_files)
    assert('successfully uploaded 1 images to label' in res['message'])

    print_test_pass()
    return res['labelId']

  def get_annotations_test(self, detector_id, label_id):
    res = self.api.get_annotations(
        detectorId=detector_id, labelId=label_id)
    assert (res['images'] != None)
    print_test_pass()

  def get_label_images_test(self, detector_id, label_id):
    res = self.api.get_label_images(
        detectorId=detector_id, labelId=label_id)
    assert(res['images'] != None)

    print_test_pass()
    return res['images'][0]['imageId']

  def update_annotations_test(self, detector_id, label_id, image_id, bbox):
    with pytest.raises(APIError) as e:
      self.api.update_annotations(
          detectorId=detector_id, labelId=label_id, images=[])
    assert ('invalid_query_err' in str(e))

    res = self.api.update_annotations(detectorId=detector_id, labelId=label_id, images=[
        {'id': image_id, 'bbox': bbox}])
    assert (res['message'] == 'successfully updated 1 images')
    print_test_pass()

  def update_label_with_images_test(self, detector_id, label_id, image_files):
    res = self.api.update_label_with_images(
        detectorId=detector_id, labelId=label_id, imageFiles=image_files)
    assert ('successfully uploaded 1 images to label' in res['message'])
    print_test_pass()

  def delete_label_test(self, detector_id, label_id):
    res = self.api.delete_label(
        detectorId=detector_id, labelId=label_id)
    assert (res['message'] == 'Successfully deleted the label')
    print_test_pass()

  def finalize_detector_test(self, detector_id):
    res = self.api.finalize_detector(detectorId=detector_id)
    assert (res['message'] == 'training began successfully')
    print_test_pass()

  def get_detector_info_test(self, detector_id):
    res = self.api.get_detector_info(detectorId=detector_id)
    assert (res['id'] == detector_id)
    print_test_pass()

  def search_detectors_test(self):
    res = self.api.search_detectors()
    assert (res[0]['id'] != None)
    print_test_pass()

  def list_detectors_test(self):
    res = self.api.list_detectors()
    assert (len(res) > 0)
    print_test_pass()

  def redo_detector_test(self, detector_id):
    res = self.api.redo_detector(detectorId=detector_id)
    redo_detector_id = res['detectorId']
    assert(redo_detector_id != None)

    print_test_pass()
    return redo_detector_id

  def import_detector_test(self, name, input_tensor, output_tensor, detector_type, file_proto, labels):
    res = self.api.import_detector(name=name, inputTensor=input_tensor, outputTensor=output_tensor,
                                   detectorType=detector_type, fileProto=file_proto, labels=labels)

    assert(res['detectorId'] != None)

    print_test_pass()
    return res['detectorId']

  def delete_detector_test(self, detector_id, detector_type):
    res = self.api.delete_detector(detectorId=detector_id)
    assert (res['message'] == 'Deleted detector.')
    print_test_pass()

  # helpers
  def delete_pending_detectors(self):
    res = self.api.search_detectors(state='pending')
    if len(res) == 1:
      print('Info: found a pending detector, deleting it...')
      self.api.delete_detector(detectorId=res[0]['id'])
      print('Info: Deleted pending detector')

  def wait_detector_training(self, detector_id):
    res = self.api.get_detector_info(detectorId=detector_id)

    print ('Info: waiting for detectors training')
    indicator = '.'
    max_indicator_length = 48
    while res['state'] != 'trained' and res['state'] != 'failed':
      if len(indicator) > max_indicator_length:
        pytest.fail('Timeout when waiting for detector training')

      print(indicator)
      time.sleep(5)
      res = self.api.get_detector_info(detectorId=detector_id)

      indicator += '.'

    print('Info: detector is ready')

  def wait_detector_ready_for_edit(self, detector_id):
    print('Info: waiting for pending detector to be ready for editing')
    res = self.api.get_detector_info(detectorId=detector_id)

    tried_num = 0
    max_tries = 15

    while (res['processing']):
      if tried_num > max_tries:
        pytest.fail(
            'Timeout when waiting for detector to be ready for editing')

      res = self.api.get_detector_info(detectorId=detector_id)

      time.sleep(2)

      tried_num += 1

    print('Info: detector is ready for editing.')



import os
import re
import sys

from matroid import error
from matroid.src.helpers import api_call

BASE_URL = 'https://www.matroid.com/api/v1'
DEFAULT_GRANT_TYPE = 'client_credentials'


class MatroidAPI(object):
  from matroid.src.helpers import bytes_to_mb, check_errors, format_response, save_token, Token, FileReader
  from matroid.src.accounts import get_account_info, account_info, retrieve_token
  from matroid.src.detectors import create_detector, delete_detector, finalize_detector, train_detector, get_detector_info, detector_info, import_detector, redo_detector, search_detectors, list_detectors
  from matroid.src.images import classify_image, localize_image
  from matroid.src.videos import classify_video, get_video_results
  from matroid.src.streams import create_stream, register_stream, delete_monitoring, delete_stream, get_monitoring_result, kill_monitoring, monitor_stream, search_monitorings, search_streams
  from matroid.src.labels import create_label_with_images, delete_label, get_annotations, get_label_images, update_annotations, update_label_with_images
  from matroid.src.collections import create_collection_index, create_collection, delete_collection_index, delete_collection, get_collection_task, get_collection, kill_collection_index, query_collection_by_scores, query_collection_by_image, update_collection_index

  def __init__(self, base_url=BASE_URL, client_id=None, client_secret=None, options={}):
    """
    base_url: the API endpoint
    client_id: OAuth public API key
    client_secret: OAuth private API key
    options (dict):
      set json_format to False to return API results as strings instead of objects
      set print_output to True to print the API results to the screen in addition to returning them
      set access_token with your auth token e.g., 43174a480adebf5b8e2bf39c0dcb53f1, to preload the token instead of requesting it from the server
    """

    from matroid.src.helpers import get_endpoints

    if not client_id:
      client_id = os.environ.get('MATROID_CLIENT_ID', None)

    if not client_secret:
      client_secret = os.environ.get('MATROID_CLIENT_SECRET', None)

    if not client_id or not client_secret:
      raise error.AuthorizationError(
          message='Both client_id and client_secret parameters are required')

    self.client_id = client_id
    self.client_secret = client_secret
    self.base_url = base_url
    self.token = None
    self.grant_type = DEFAULT_GRANT_TYPE
    self.json_format = options.get('json_format', True)
    self.print_output = options.get('print_output', False)
    self.filereader = self.FileReader()

    token = options.get('access_token')

    if token:
      token_type = 'Bearer'
      # if the token's lifetime is shorter than this, the client will request a refresh automatically
      lifetime_in_seconds = 7 * 24 * 60 * 60
      self.token = self.Token(token_type, token, lifetime_in_seconds)

    self.endpoints = get_endpoints(self.base_url)


Matroid = MatroidAPI



import pytest

from test.data import TEST_IMAGE_URL, EVERYDAY_OBJECT_DETECTOR_ID, TEST_VIDEO_URL, RANDOM_MONGO_ID
from matroid.error import InvalidQueryError, APIError
from test.helper import print_test_pass


class TestVideos(object):
  def test_videos(self, set_up_client):
    threshold = 0.3

    # set up client
    self.api = set_up_client

    # start testing
    video_id = self.classify_video_test(
        detector_id=EVERYDAY_OBJECT_DETECTOR_ID, url=TEST_VIDEO_URL)
    self.get_video_results_test(video_id=video_id, threshold=threshold)

  def classify_video_test(self, detector_id, url):
    with pytest.raises(APIError) as e:
      self.api.classify_video(detectorId=detector_id, url='invalid-url')
    assert ('invalid_query_err' in str(e))

    res = self.api.classify_video(
        detectorId=detector_id, url=url)
    video_id = res['videoId']
    assert(video_id != None)

    print_test_pass()
    return video_id

  def get_video_results_test(self, video_id, threshold):
    with pytest.raises(APIError) as e:
      self.api.classify_video(detectorId=RANDOM_MONGO_ID, url='invalid-url')
    assert ('invalid_query_err' in str(e))

    res = self.api.get_video_results(
        videoId=video_id, threshold=threshold)
    assert (res != None)

    print_test_pass()



class APIError(Exception):
  """doc"""

  def __init__(self, response=None, message=None):
    if message:
      super(APIError, self).__init__(message)
    else:
      try:
        super(APIError, self).__init__(response.text)
      except AttributeError:
        super(APIError, self).__init__(
            'No response or error message provided')

    if response:
      self.response = response

      try:
        request = response.request
        self.res_text = response.text
        self.res_status = response.status_code
        self.req_headers = request.headers
        self.req_body = request.body
      except AttributeError:
        pass

      self.message = message

    def __str__(self):
      return unicode(self).encode('utf-8')


class APIConnectionError(APIError):
  pass


class AuthorizationError(APIError):
  pass


class InvalidQueryError(APIError):
  pass


class ServerError(APIError):
  pass


class RateLimitError(APIError):
  pass


class PaymentError(APIError):
  pass


class TokenExpirationError(APIError):
  pass


class MediaError(APIError):
  pass



import os
import sys

sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'matroid'))
from version import VERSION

try:
  from setuptools import setup
except ImportError:
  from distutils.core import setup

setup(
    name='matroid',
    version=VERSION,
    description='Matroid API Python Library',
    author='Matroid',
    author_email='support@matroid.com',
    url='https://github.com/matroid/matroid-python',
    install_requires=['requests'],
    packages=['matroid'],
    use_2to3=True
)



import pytest
import inspect

from matroid.error import APIError
from test.helper import print_test_pass


class TestAccounts(object):
  def test_accounts(self, set_up_client):
    # set up client
    self.api = set_up_client

    # start testing
    self.get_account_info_test()
    self.account_info_test()
    self.retrieve_token()

  # test cases
  def get_account_info_test(self):
    res = self.api.get_account_info()
    assert (res['account'] != None)
    assert (res['account']['name'] != None)
    assert (res['account']['email'] != None)
    print_test_pass()

  # test deprecated method name (account_info, now get_account_info)
  def account_info_test(self):
      res = self.api.account_info()
      assert (res['account'] != None)
      assert (res['account']['name'] != None)
      assert (res['account']['email'] != None)
      print_test_pass()

  def retrieve_token(self):
    res = self.api.retrieve_token()
    assert (res != None)
    assert (res.token_type != None)
    assert (res.token_str != None)
    print_test_pass()

  def test_with_wrong_permission(self, set_up_wrong_permission_client):
    with pytest.raises(APIError) as e:
      api = set_up_wrong_permission_client
      api.retrieve_token()
    assert ('authorization_err' in str(e))
    print_test_pass()



import pytest

from test.data import TEST_IMAGE_URL, TEST_IMAGE_URL_DOG, TEST_IMAGE_FILE, TEST_IMAGE_FILE_DOG, EVERYDAY_OBJECT_DETECTOR_ID
from matroid.error import InvalidQueryError, APIError
from test.helper import print_test_pass


class TestImages(object):
  def test_images(self, set_up_client):
    localizer_label = 'cat'
    urls = [TEST_IMAGE_URL, TEST_IMAGE_URL_DOG]
    files = [TEST_IMAGE_FILE_DOG, TEST_IMAGE_FILE]

    # set up client
    self.api = set_up_client

    # start testing
    # self.classify_image_test(
    #     detector_id=EVERYDAY_OBJECT_DETECTOR_ID, url=TEST_IMAGE_URL, file=TEST_IMAGE_FILE, urls=urls, files=files)
    self.localize_image_test(
        localizer=EVERYDAY_OBJECT_DETECTOR_ID, localizer_label=localizer_label, url=TEST_IMAGE_URL)

  def classify_image_test(self, detector_id, url, urls, file, files):
    with pytest.raises(APIError) as e:
      # self.api.classify_image(detectorId=detector_id, url='invalid-url')
      self.api.classify_image(detectorId=detector_id)
    assert ('invalid_query_err' in str(e))
    print('Classify invalid url test passed')

    res = self.api.classify_image(detectorId=detector_id, url=url)
    assert (res['results'][0]['predictions'] != None)
    print('Classify one url test passed')

    res = self.api.classify_image(detectorId=detector_id, file=file)
    assert (res['results'][0]['predictions'] != None)
    print('Classify one file test passed')

    res = self.api.classify_image(detectorId=detector_id, file=files)
    assert(len(res['results']) == 2)
    assert (res['results'][0]['predictions'] != None)
    print('Classify multiple files test passed')

    res = self.api.classify_image(detectorId=detector_id, url=urls)
    assert(len(res['results']) == 2)
    assert (res['results'][0]['predictions'] != None)
    print ('Classify multiple urls test passed')

    print_test_pass()

  def localize_image_test(self, localizer, localizer_label, url):
    res = self.api.localize_image(
        localizer=localizer, localizerLabel=localizer_label, url=url)
    assert (res['results'][0]['predictions'] != None)

    print_test_pass()



import time
from datetime import datetime
import pytest

from test.data import EVERYDAY_OBJECT_DETECTOR_ID, TEST_IMAGE_URL, RANDOM_MONGO_ID
from matroid.error import InvalidQueryError, APIError
from test.helper import print_test_pass

COLLECTION_NAME = 'py-test-collection-{}'.format(datetime.now())
S3_BUCKET_URL = 's3://bucket/m-test-public/'


class TestCollections(object):

  def test_collections(self, set_up_client):
    collection_id = None
    task_id = None

    # set up client
    self.api = set_up_client
    task_killed = False

    # start testing
    try:
      collection_id = self.create_collection_test()
      task_id = self.create_collection_index_test(collection_id)
      self.get_collection_test(collection_id)
      self.get_collection_task_test(task_id)
      self.kill_collection_index_test(task_id)
      task_killed = True
      self.wait_for_collection_index_stop(task_id)
      self.update_collection_index_test(task_id)
      task_killed = False
    finally:
      if task_id:
        if not task_killed:
          self.kill_collection_index_test(task_id)
        self.wait_for_collection_index_stop(task_id)
        self.delete_collection_index_test(task_id)
      if collection_id:
        self.delete_collection_test(collection_id)

  # test cases
  def create_collection_test(self):
    with pytest.raises(APIError) as e:
      self.api.create_collection(
          name='invalid-collection', url='invalid-url', sourceType='s3')
    assert ('invalid_query_err' in str(e))

    # should create collection with correct params
    sourceType = 's3'
    res = self.api.create_collection(
        name=COLLECTION_NAME, url=S3_BUCKET_URL, sourceType=sourceType)
    collection_id = res['collection']['_id']
    assert(collection_id != None)
    assert (res['collection']['name'] == COLLECTION_NAME)
    assert (res['collection']['url'] == S3_BUCKET_URL)
    assert (res['collection']['sourceType'] == sourceType)
    assert (len(res['collection']['detectingTasks']) == 0)

    print_test_pass()
    return collection_id

  def create_collection_index_test(self, collection_id):
    with pytest.raises(APIError) as e:
      self.api.create_collection_index(
          collectionId=collection_id, detectorId=RANDOM_MONGO_ID, fileTypes='images')
    assert ('invalid_query_err' in str(e))

    res = self.api.create_collection_index(
        collectionId=collection_id, detectorId=EVERYDAY_OBJECT_DETECTOR_ID, fileTypes='images')
    task_id = res['collectionTask']['_id']
    assert (task_id != None)

    print_test_pass()
    return task_id

  def get_collection_test(self, collection_id):
    res = self.api.get_collection(collectionId=collection_id)
    collection = res['collection']
    assert(collection['_id'] == collection_id)
    assert (collection['name'] == COLLECTION_NAME)
    print_test_pass()

  def get_collection_task_test(self, task_id):
    res = self.api.get_collection_task(taskId=task_id)
    assert(res['collectionTask'] != None)
    collection_task_id = res['collectionTask']['_id']
    assert (collection_task_id == task_id)
    print_test_pass()

  def update_collection_index_test(self, task_id):
    res = self.api.update_collection_index(
        taskId=task_id, updateIndex=False)
    assert(res['collectionTask'] != None)
    collection_task_id = res['collectionTask']['_id']
    assert (collection_task_id == task_id)
    print_test_pass()

  def query_collection_by_scores_test(self, task_id):
    print(task_id)
    res = self.api.query_collection_by_scores(
        taskId=task_id, thresholds={'cat': 0.5}, numResults=5)
    assert (res['results'] != None)
    print_test_pass()

  def query_collection_by_image_test(self, task_id, url):
    res = self.api.query_collection_by_image(taskId=task_id, numResults=1, url=url, boundingBox={
        "top": 0.1, "left": 0.1, "height": 0.8, "width": 0.8})
    assert (res['results'] != None)
    print_test_pass()

  def kill_collection_index_test(self, task_id):
    res = self.api.kill_collection_index(
        taskId=task_id, includeCollectionInfo=False)
    collection_task = res['collectionTask']
    assert(collection_task != None)
    assert (collection_task['_id'] == task_id)
    print_test_pass()

  def delete_collection_index_test(self, task_id):
    res = self.api.delete_collection_index(taskId=task_id)
    assert (res['message'] == 'Successfully deleted')
    print_test_pass()

  def delete_collection_test(self, collection_id):
    res = self.api.delete_collection(collectionId=collection_id)
    assert (res['message'] == 'Successfully deleted')
    print_test_pass()

  # helpers
  def wait_for_collection_index_stop(self, task_id):
    print('Info: waiting for collection task to stop')
    res = self.api.get_collection_task(taskId=task_id)

    tried_num = 0
    max_tries = 15
    while (res['collectionTask']['state'] != 'failed'):
      if tried_num > max_tries:
        pytest.fail('Timeout when waiting for collection index to stop')

      res = self.api.get_collection_task(taskId=task_id)
      time.sleep(2)

      tried_num += 1

    print('Info: collection task stopped.')
